@@ -11,7 +11,17 @@ class CompletionClient:
         self._headers = {"Authorization": f"Bearer {token}"}
         self._session = session
 
-    def generate_response(self, prompt: str, model: str = "text-davinci-003") -> str:
+    def generate_response(self, prompt: str, model: str) -> str:
+        """Generates response from a given prompt using a specified model.
+
+        Args:
+            prompt: The prompt to generate a response for.
+            model: The model to use for generating the response.
+                   Defaults to "text-davinci-003".
+
+        Returns:
+            The generated response.
+        """
         response = self._session.post(
             self.API_URL,
             headers=self._headers,
